@@ -38,10 +38,10 @@
 namespace svn
 {
 
-void Client_impl::merge_reintegrate(const MergeParameter &parameters) throw (ClientException)
+void Client_impl::merge_reintegrate(const MergeParameter &parameters)
 {
     Pool pool;
-    svn_error_t *error = 0;
+    svn_error_t *error = nullptr;
     error = svn_client_merge_reintegrate(parameters.path1().cstr(),
                                          parameters.peg().revision(),
                                          parameters.localPath().cstr(),
@@ -50,25 +50,21 @@ void Client_impl::merge_reintegrate(const MergeParameter &parameters) throw (Cli
                                          *m_context,
                                          pool
                                         );
-    if (error != 0) {
+    if (error != nullptr) {
         throw ClientException(error);
     }
 }
 
-void Client_impl::merge(const MergeParameter &parameters) throw (ClientException)
+void Client_impl::merge(const MergeParameter &parameters)
 {
     Pool pool;
-    svn_error_t *error = 0;
+    svn_error_t *error = nullptr;
     if (parameters.reintegrate()) {
         merge_reintegrate(parameters);
     } else {
       // todo svn 1.8: svn_client_merge5
         error =
-#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
             svn_client_merge4
-#else
-            svn_client_merge3
-#endif
             (parameters.path1().cstr(),
              parameters.revision1().revision(),
              parameters.path2().cstr(),
@@ -79,31 +75,25 @@ void Client_impl::merge(const MergeParameter &parameters) throw (ClientException
              parameters.force(),
              parameters.record_only(),
              parameters.dry_run(),
-#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
              parameters.allow_mixed_rev(),
-#endif
              parameters.merge_options().array(pool),
              *m_context,
              pool);
     }
 
-    if (error != 0) {
+    if (error != nullptr) {
         throw ClientException(error);
     }
 }
 
-void Client_impl::merge_peg(const MergeParameter &parameters) throw (ClientException)
+void Client_impl::merge_peg(const MergeParameter &parameters)
 {
     Pool pool;
     internal::RevisionRangesToHash _rhash(parameters.revisions());
 
     // todo svn 1.8: svn_client_merge_peg5
     svn_error_t *error =
-#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
         svn_client_merge_peg4
-#else
-        svn_client_merge_peg3
-#endif
         (
             parameters.path1().cstr(),
             _rhash.array(pool),
@@ -114,14 +104,12 @@ void Client_impl::merge_peg(const MergeParameter &parameters) throw (ClientExcep
             parameters.force(),
             parameters.record_only(),
             parameters.dry_run(),
-#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
             parameters.allow_mixed_rev(),
-#endif
             parameters.merge_options().array(pool),
             *m_context,
             pool
         );
-    if (error != 0) {
+    if (error != nullptr) {
         throw ClientException(error);
     }
 }
